#include <Wire.h> //I2C Arduino Library
#include "pitches.h"

#define address 0x1D   // I2C 7bit address of LSM303C


// notes in the melody:
int melody[] = {
  NOTE_C4, NOTE_G3,NOTE_G3, NOTE_A3, NOTE_G3,0, NOTE_B3, NOTE_C4};

// note durations: 4 = quarter note, 8 = eighth note, etc.:
int noteDurations[] = {
  4, 8, 8, 4,4,4,4,4 };

void setup(){
  //Initialize Serial and I2C communications
  Serial.begin(9600);
  Wire.begin();
  
  //Put the LSM303C into the correct operating mode
  Wire.beginTransmission(address); //open communication with LSM303C
  Wire.write(0x20); //select mode register
  Wire.write(0x17); //continuous measurement mode
  Wire.endTransmission();
    
}


 void speaker(){
    // iterate over the notes of the melody:
  for (int thisNote = 0; thisNote < 8; thisNote++) {

    // to calculate the note duration, take one second 
    // divided by the note type.
    //e.g. quarter note = 1000 / 4, eighth note = 1000/8, etc.
    int noteDuration = 1000/noteDurations[thisNote];
    tone(8, melody[thisNote],noteDuration);

    // to distinguish the notes, set a minimum time between them.
    // the note's duration + 30% seems to work well:
    int pauseBetweenNotes = noteDuration * 1.30;
    delay(pauseBetweenNotes);
    // stop the tone playing:
    noTone(8);
  }
 }

 void loop(){
  
  int x,y,z; //triple axis data

  //Tell the LSM303C where to begin reading data
  Wire.beginTransmission(address);
  Wire.write(0x28); //select register X_LOW register
  Wire.endTransmission();
  
 
 //Read data from each axis, 2 registers per axis
  Wire.requestFrom(address, 6);
  if(6<=Wire.available()){
    x |= Wire.read(); //X lsb
    x = Wire.read()<<8; //X hsb
    y |= Wire.read(); //Y lsb
    y = Wire.read()<<8; //Y msb
    z |= Wire.read(); //Z lsb
    z = Wire.read()<<8; //Z msb
  }
  
  //Print out values of each axis
  Serial.print("x: ");
  Serial.print(x);
  Serial.print("  y: ");
  Serial.print(y);
  Serial.print("  z: ");
  Serial.println(z);
  
  delay(250);
  
  if (z > 768)
  {
    speaker();
  }
  
  
}

